==> haskell-simple-smt-0.9.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-smt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-smt
version:              0.9.4
visibility:           public
id:                   simple-smt-0.9.4-EhYVNSyzChx8Xewxp0UW8O
key:                  simple-smt-0.9.4-EhYVNSyzChx8Xewxp0UW8O
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A simple way to interact with an SMT solver process.
description:          A simple way to interact with an SMT solver process.
category:             Math
abi:                  2e7a3c7f1bafe5e6cc1186de509d4ab7
exposed:              True
exposed-modules:      SimpleSMT
import-dirs:          /usr/lib/ghc-8.8.1/site-local/simple-smt-0.9.4
library-dirs:         /usr/lib/ghc-8.8.1/site-local/simple-smt-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/simple-smt-0.9.4
hs-libraries:         HSsimple-smt-0.9.4-EhYVNSyzChx8Xewxp0UW8O
depends:              base-4.13.0.0 process-1.6.5.1
haddock-interfaces:   /usr/share/doc/haskell-simple-smt/html/simple-smt.haddock
haddock-html:         /usr/share/doc/haskell-simple-smt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-smt-0.9.4-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-smt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-smt
version:              0.9.4
visibility:           public
id:                   simple-smt-0.9.4-5yfBEHJdlRlHbDJMhrBDYb
key:                  simple-smt-0.9.4-5yfBEHJdlRlHbDJMhrBDYb
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A simple way to interact with an SMT solver process.
description:          A simple way to interact with an SMT solver process.
category:             Math
abi:                  bffb79e13eacd7a0dc7ce48b77b76277
exposed:              True
exposed-modules:      SimpleSMT
import-dirs:          /usr/lib/ghc-8.8.2/site-local/simple-smt-0.9.4
library-dirs:         /usr/lib/ghc-8.8.2/site-local/simple-smt-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/simple-smt-0.9.4
hs-libraries:         HSsimple-smt-0.9.4-5yfBEHJdlRlHbDJMhrBDYb
depends:              base-4.13.0.0 process-1.6.7.0
haddock-interfaces:   /usr/share/doc/haskell-simple-smt/html/simple-smt.haddock
haddock-html:         /usr/share/doc/haskell-simple-smt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
